/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;

/**
 * <p>
 * This class is derived from Server class and is the base class for all classes representing data server to be used
 * while running tests.
 * Those classes will have corresponding elements in the Ant build file.
 * </p>
 *
 * <p>
 * This class is a base for another component which will provide testing ability for database servers.
 * TestCase extension classes should also be provided by that component too.
 * </p>
 *
 * <p>
 * Besides the attributes supported by Server class, here is the extra attributes supported by DataServer class:
 * <ul>
 * <li>"jarfile" - JAR archive which contains data needed for data server initialization, the implementation defines
 * whether required or not</li>
 * </ul>
 * </p>
 *
 * <p>
 * Thread Safety : This class is mutable and so not thread-safe.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public abstract class DataServer extends Server {
    /**
     * <p>
     * This variable represents the "jarFile" attribute.
     * </p>
     *
     * <p>
     * "jarFile" attribute specifies the JAR archive which contains data needed for data server initialization.
     * Derived classes should determine if this attribute is required.
     * </p>
     *
     * <p>
     * Initially is null, later can be set by the setJarFile() method.
     * </p>
     *
     */
    private File jarFile;

    /**
     * <p>
     * Creates an instance of DataServer class.
     * The type of server represented by the class is specified.
     * </p>
     *
     * <p>
     * Type can be a sting like "mysql4x", which actually specifies the name and version of the server.
     * </p>
     *
     * @param type the type of the server
     * @throws org.apache.tools.ant.BuildException if the type of the server is unrecognized, or any other error happens
     * @throws IllegalArgumentException if type is null or empty
     */
    protected DataServer(String type) {
        super(type);
    }

    /**
     * <p>
     * Sets the value of the "jarfile" attribute.
     * </p>
     *
     * <p>
     * "jarFile" attribute specifies the JAR archive which contains data needed for data server initialization.
     * </p>
     *
     * <p>
     * Note, this method is intended to be called by ANT engine.
     * </p>
     *
     * @param jarFile the value of the "jarfile" attribute
     */
    public void setJarFile(File jarFile) {
        this.jarFile = jarFile;
    }

    /**
     * <p>
     * Returns the value of the "jarfile" attribute.
     * </p>
     *
     * <p>
     * "jarfile" attribute specifies the JAR archive which contains data needed for data server initialization.
     * </p>
     *
     * @return the value of the "jarfile" attribute
     */
    public File getJarFile() {
        return this.jarFile;
    }
}