/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Target;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for AntTaskInfo.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class AntTaskInfoTests extends TestCase {
    /**
     * <p>
     * Project instance for constructing AntTaskInfo instance.
     * </p>
     */
    private Project project;

    /**
     * <p>
     * TaskName for constructing AntTaskInfo instance.
     * </p>
     */
    private String taskName;

    /**
     * <p>
     * Location instance for constructing AntTaskInfo instance.
     * </p>
     */
    private Location location;

    /**
     * <p>
     * Target instance for constructing AntTaskInfo instance.
     * </p>
     */
    private Target target;

    /**
     * <p>
     * AntTaskInfo instance for testing.
     * </p>
     */
    private AntTaskInfo antTaskInfo;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        project = TestHelper.getProject(TestHelper.SAMPLE_BUILD_XML);
        taskName = "javac";
        location = new Location(TestHelper.SAMPLE_BUILD_XML);
        target = (Target) project.getTargets().get("compile");

        antTaskInfo = new AntTaskInfo(project, taskName, location, target);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        project = null;
        taskName = null;
        location = null;
        target = null;
        antTaskInfo = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(AntTaskInfoTests.class);
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for accuracy.
     * Expects a new AntTaskInfo instance created successfully.
     * </p>
     */
    public void testCtor1() {
        assertNotNull("Failed to create new AntTaskInfo instance.", antTaskInfo);
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for failure.
     * It tests the case that when project is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_NullProject() {
        try {
            new AntTaskInfo(null, taskName, location, target);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for failure.
     * It tests the case that when taskName is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_NullTaskName() {
        try {
            new AntTaskInfo(project, null, location, target);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for failure.
     * It tests the case that when taskName is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_EmptyTaskName() {
        try {
            new AntTaskInfo(project, " ", location, target);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for failure.
     * It tests the case that when location is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_NullLocation() {
        try {
            new AntTaskInfo(project, taskName, null, target);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor AntTaskInfo#AntTaskInfo(Project,String,Location,Target) for failure.
     * It tests the case that when target is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_NullTarget() {
        try {
            new AntTaskInfo(project, taskName, location, null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests AntTaskInfo#getLocation() for accuracy.
     * Expects equal location instance.
     * </p>
     */
    public void testGetLocation() {
        assertEquals("Failed to get correct file name.", location.getFileName(),
                antTaskInfo.getLocation().getFileName());
        assertEquals("Failed to get correct line number", location.getLineNumber(),
                antTaskInfo.getLocation().getLineNumber());
    }

    /**
     * <p>
     * Tests AntTaskInfo#getProject() for accuracy.
     * Expects equal project instance.
     * </p>
     */
    public void testGetProject() {
        assertEquals("Failed to get correct project name.", project.getName(), antTaskInfo.getProject().getName());
        assertEquals("Failed to get correct default target.", project.getDefaultTarget(),
                antTaskInfo.getProject().getDefaultTarget());
        assertEquals("Failed tog get correct targets.", project.getTargets(), antTaskInfo.getProject().getTargets());
    }

    /**
     * <p>
     * Tests AntTaskInfo#getTaskName() for accuracy.
     * Expects equal taskName.
     * </p>
     */
    public void testGetTaskName() {
        assertEquals("Failed to get correct taskName.", taskName, antTaskInfo.getTaskName());
    }

    /**
     * <p>
     * Tests AntTaskInfo#getTarget() for accuracy.
     * Expects equal task instance.
     * </p>
     */
    public void testGetTarget() {
        assertEquals("Failed to get correct target name.",
                target.getName(), antTaskInfo.getTarget().getName());
        assertEquals("Failed to get correct tasks.",
                target.getTasks().length, antTaskInfo.getTarget().getTasks().length);
    }

}