/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for CredentialsElement.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class CredentialsElementTests extends TestCase {
    /**
     * <p>
     * CredentialsElement instance for testing.
     * </p>
     */
    private CredentialsElement credentialsElement;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        credentialsElement = new CredentialsElement();
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        credentialsElement = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(CredentialsElementTests.class);
    }

    /**
     * <p>
     * Tests ctor CredentialsElement#CredentialsElement() for accuracy.
     * Expects a new CredentialsElement instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new CredentialsElement instance.", credentialsElement);
    }

    /**
     * <p>
     * Tests CredentialsElement#createDynamicElement(String) for accuracy.
     * Expects a password property is created successfully.
     * </p>
     */
    public void testCreateDynamicElement() {
        Object obj = credentialsElement.createDynamicElement(Server.PASSWORD);

        assertNotNull("Expects a not null CredentialProperty object.", obj);
        assertTrue("Expects a CredentialProperty object.", obj instanceof CredentialProperty);
    }

    /**
     * <p>
     * Tests CredentialsElement#createDynamicElement(String) for failure.
     * It tests the case that when name is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_NullName() {
        try {
            credentialsElement.createDynamicElement(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests CredentialsElement#createDynamicElement(String) for failure.
     * It tests the case that when name is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_EmptyName() {
        try {
            credentialsElement.createDynamicElement(" ");
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests CredentialsElement#getPropretyMap() for accuracy.
     * Expects the propertyMap is initially empty.
     * </p>
     */
    public void testGetPropretyMap() {
        assertTrue("Expects empty property map.", credentialsElement.getPropertyMap().isEmpty());
    }

    /**
     * <p>
     * Tests CredentialsElement#getPropretyMap() for accuracy.
     * It tests a new property is added to credentialsElement and expects it can be retrieved correctly.
     * </p>
     */
    public void testGetPropretyMap2() {
        CredentialProperty property = (CredentialProperty) credentialsElement.createDynamicElement(Server.PASSWORD);
        property.setValue("TOPCODER");

        // check size
        assertEquals("Expects one property in the credentialsElement.", 1,
                credentialsElement.getPropertyMap().size());

        // check property value
        assertEquals("Failed to get correct password property value.", "TOPCODER",
                credentialsElement.getPropertyMap().get(Server.PASSWORD));
    }
}