/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Target;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for ServerAppTestTask.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */

public class ServerAppTestTaskTests extends TestCase {
    /**
     * <p>
     * The class name of default server implementation.
     * </p>
     */
    private static final String SERVER_CLASS = "com.topcoder.testframework.web.DefaultWebApplicationServer";

    /**
     * <p>
     * Project instance used for integration unit testing ServerAppTestTask.
     * </p>
     */
    private Project project;

    /**
     * <p>
     * ServerAppTestTask instance for testing.
     * </p>
     */
    private ServerAppTestTask task;

    /**
     * <p>
     * Default Constructor.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public ServerAppTestTaskTests() throws Exception {
        project = TestHelper.getProject("test_files/ServerAppTestTask.xml");
    }

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    protected void setUp() throws Exception {
        task = new ServerAppTestTask();
        task.setProject(new Project());
        task.setLocation(Location.UNKNOWN_LOCATION);
        task.setTaskName("serverapptest");
        task.setOwningTarget(new Target());
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        task = null;

        TestHelper.clearTempFiles();
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(ServerAppTestTaskTests.class);
    }

    /**
     * <p>
     * Tests ctor ServerAppTestTask#ServerAppTestTask() for accuracy.
     * Expects a new ServerAppTestTask instance created successfully.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testCtor() throws Exception {
        assertNotNull("Failed to create new ServerAppTestTask instance.", new ServerAppTestTask());
    }

    /**
     * <p>
     * Tests ServerAppTestTask#execute() for accuracy.
     * This test case runs ServerAppTestTask using Ant API.
     * </p>
     *
     * <p>
     * The target to execute:
     *   &lt;serverapptest printsummary=&quot;yes&quot; failureproperty=&quot;tests.failed&quot;
     *   reportsDir=&quot;log&quot;&gt;
     *       &lt;com.topcoder.testframework.web.DefaultWebApplicationServer&gt;
     *           &lt;tomcat5x warfile=&quot;sample.war&quot; dir=&quot;${tomcat5x.home}&quot; port=&quot;8080&quot;/&gt;
     *       &lt;/com.topcoder.testframework.web.DefaultWebApplicationServer&gt;
     *       &lt;formatter type=&quot;xml&quot;/&gt;
     *   &lt;/serverapptest&gt;
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testExecute() throws Exception {
        project.executeTarget("test1");
    }

    /**
     * <p>
     * Tests ServerAppTestTask#execute() for failure.
     * This test case runs ServerAppTestTask using Ant API.
     * </p>
     *
     * <p>
     * It tests the case when the Server class name can't be found in classpath and expect BuildException.
     * </p>
     *
     * <p>
     * The target to execute:
     *   &lt;serverapptest printsummary=&quot;yes&quot; failureproperty=&quot;tests.failed&quot;
     *   reportsDir=&quot;log&quot;&gt;
     *       &lt;NoServer&gt;
     *           &lt;tomcat5x warfile=&quot;sample.war&quot; dir=&quot;${tomcat5x.home}&quot; port=&quot;8080&quot;/&gt;
     *       &lt;/NoServer&gt;
     *       &lt;formatter type=&quot;xml&quot;/&gt;
     *   &lt;/serverapptest&gt;
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testExecute2() throws Exception {
        try {
            project.executeTarget("test2");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerAppTestTask#execute() for failure.
     * This test case runs ServerAppTestTask using Ant API.
     * </p>
     *
     * <p>
     * It tests the case when the type is not supported by the Server class and expects BuildExcepiton.
     * </p>
     *
     * <p>
     * The target to execute:
     *   &lt;serverapptest printsummary=&quot;yes&quot; failureproperty=&quot;tests.failed&quot;
     *   reportsDir=&quot;log&quot;&gt;
     *       &lt;com.topcoder.testframework.web.DefaultWebApplicationServer&gt;
     *           &lt;topcoderserver warfile=&quot;sample.war&quot; dir=&quot;${tomcat5x.home}&quot;
     *           port=&quot;8080&quot;/&gt;
     *       &lt;/com.topcoder.testframework.web.DefaultWebApplicationServer&gt;
     *       &lt;formatter type=&quot;xml&quot;/&gt;
     *   &lt;/serverapptest&gt;
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testExecute3() throws Exception {
        try {
            project.executeTarget("test3");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerAppTestTask#createDynamicElement(String, String, String) for accuracy.
     * Expects a new ServerElement instance created successfully.
     * </p>
     */
    public void testCreateDynamicElement() {
        Object obj = task.createDynamicElement(null, SERVER_CLASS, SERVER_CLASS);

        assertNotNull("Expects not null ServerElement object", obj);
        assertTrue("Expects the created object be type of ServerElement.", obj instanceof ServerElement);
    }

    /**
     * <p>
     * Tests ServerAppTestTask#createDynamicElement(String) for failure.
     * It tests the case that when localName is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_NullLocalName() {
        try {
            task.createDynamicElement(null, null, SERVER_CLASS);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerAppTestTask#createDynamicElement(String) for failure.
     * It tests the case that when localName is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_EmptyLocalName() {
        try {
            task.createDynamicElement(null, " ", SERVER_CLASS);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerAppTestTask#setReportsDir(File) for accuracy.
     * Expects reportsDir attribute is correctly set.
     * </p>
     */
    public void testSetReportsDir() {
        File dir = new File("test_files");
        task.setReportsDir(dir);

        assertEquals("Failed to get correct resportsDir file name.", "test_files", task.getReportsDir().getName());
    }

    /**
     * <p>
     * Tests ServerAppTestTask#getReportsDir() for accuracy.
     * Expects reportsDir is initially null.
     * </p>
     */
    public void testGetReportsDir() {
        assertNull("Expects null reportsDir file.", task.getReportsDir());
    }
}