/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import java.io.IOException;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import com.topcoder.testframework.TestHelper;

/**
 * <p>
 * This class implements Filter interface and it is used for demo purpose.
 * </p>
 *
 * <p>
 * In this filter, HSQL database is used and the HSQL database server is managed by this component.
 * </p>
 *
 * <p>
 * The test case for this filter implementation is TestDBBasedFilter, it is based on the Testing Framework
 * component and demonstrates how to write test case under Testing Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DBBasedFilter implements Filter {

    /**
     * <p>
     * This method implements Filter#init(FilterConfig) and in current implementation, it does nothing.
     * </p>
     *
     * @param filterConfig the FilterConfig instance
     *
     * @throws ServletException when initialization fails.
     */
    public void init(FilterConfig filterConfig) throws ServletException {
        // ignore
    }

    /**
     * <p>
     * This method implements Filter#doFilter(ServletRequest,ServletResponse,FilterChain) method.
     * </p>
     *
     * <p>
     * It checks the action parameter in request, if its value occurs in HSQL database, then forward to success
     * html page, otherwise, forward to error html page.
     * </p>
     *
     * @param request The HttpRequest instance.
     * @param response The HttpResponse instance.
     * @param filterChain The FilterChain instance.
     *
     * @throws IOException when any exception which is due to input/output problems occurs.
     * @throws ServletException when the request cannot be handled.
     */
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain filterChain)
        throws IOException, ServletException {
        String value = request.getParameter("action");
        boolean isAuthorized = false;
        Connection connection = null;
        try {
            // obtain a database connection
            connection = TestHelper.getConnection("sa", "");

            Statement statement = connection.createStatement();

            // query the ACTION table to see whether it contains the action value in request instance
            ResultSet rs = statement.executeQuery("SELECT * FROM ACTION");
            while (rs.next()) {
                String action = rs.getString(1);

                // if found, then exit loop and close statement
                if (action.equals(value)) {
                    isAuthorized = true;
                    break;
                }
            }

            // release database resource
            rs.close();

        } catch (SQLException e) {
            // ignore
        } finally {

            // release database connection resource
            TestHelper.closeConnection(connection);
        }

        // forward to different page depends on the flag isAuthorized.
        if (!isAuthorized) {
            RequestDispatcher dispatcher = request.getRequestDispatcher("/error.html");
            dispatcher.forward(request, response);
        } else {
            RequestDispatcher dispatcher = request.getRequestDispatcher("/success.html");
            dispatcher.forward(request, response);
        }
    }

    /**
     * <p>
     * This method implements Filter#destroy() and in current implementation, it does nothing.
     * </p>
     *
     */
    public void destroy() {
        // ignore
    }

}
