/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;

import com.topcoder.testframework.web.TCFilterTestCase;

/**
 * <p>
 * This test case extends TCFilterTestCase and is used for testing class DBBasedFilter.
 * </p>
 *
 * <p>
 * Note, it is based on the Testing Framework component and demonstrates how to write test case under Testing
 * Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestDBBasedFilter extends TCFilterTestCase {
    /**
     * <p>
     * Default constructor.
     * </p>
     *
     */
    public TestDBBasedFilter() {
        super();
    }

    /**
     * <p>
     * Constructs a test case with the given name.
     * <p>
     *
     * @param name the name of the test case
     */
    public TestDBBasedFilter(String name) {
        super(name);
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(TestDBBasedFilter.class);
    }

    /**
     * <p>
     * Initializes the action parameter in request with value 'update'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginDoDBBasedFilterNotAllowed(WebRequest request) {
        request.addParameter("action", "update");
    }

    /**
     * <p>
     * Calls doFilter() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testDoDBBasedFilterNotAllowed() throws Exception {
        DBBasedFilter filter = new DBBasedFilter();
        filter.doFilter(getRequest(), getResponse(), getFilterChain());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects error page returned.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endDoDBBasedFilterNotAllowed(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text.", content, "Error Page");
    }

    /**
     * <p>
     * Initializes the action parameter in request with value 'select'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginDoDBBasedFilterAllowed(WebRequest request) {
        request.addParameter("action", "select");
    }

    /**
     * <p>
     * Calls doFilter() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testDoDBBasedFilterAllowed() throws Exception {
        DBBasedFilter filter = new DBBasedFilter();
        filter.doFilter(getRequest(), getResponse(), getFilterChain());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects success page returned.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endDoDBBasedFilterAllowed(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text.", content, "Success Page");
    }

}
