/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;

import com.topcoder.testframework.web.TCFilterTestCase;

/**
 * <p>
 * This test case extends TCFilterTestCase and is used for testing class SimpleFilter.
 * </p>
 *
 * <p>
 * Note, it is based on the Testing Framework component and demonstrates how to write test case under Testing
 * Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestSimpleFilter extends TCFilterTestCase {

    /**
     * <p>
     * Default constructor.
     * </p>
     *
     */
    public TestSimpleFilter() {
        super();
    }

    /**
     * <p>
     * Constructs a test case with the given name.
     * <p>
     *
     * @param name the name of the test case
     */
    public TestSimpleFilter(String name) {
        super(name);
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(TestSimpleFilter.class);
    }

    /**
     * <p>
     * Initializes the site parameter in request with value 'topcoder'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginDoFilterAllowed(WebRequest request) {
        request.addParameter("site", "topcoder");

        // test the implicit objects
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null filterChain instance.", this.getFilterChain());
        assertNull("Expects null config instance.", this.getConfig());
    }

    /**
     * <p>
     * Calls doFilter() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testDoFilterAllowed() throws Exception {
        // test the implicit objects
        assertNotNull("Expects not null request instance.", this.getRequest());
        assertNotNull("Expects not null response instance.", this.getResponse());
        assertNotNull("Expects not null filterChain instance.", this.getFilterChain());
        assertNotNull("Expects not null config instance.", this.getConfig());

        SimpleFilter filter = new SimpleFilter();
        filter.doFilter(getRequest(), getResponse(), getFilterChain());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects success page returned.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endDoFilterAllowed(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text.", content, "Success Page");

        // test the implicit objects
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null filterChain instance.", this.getFilterChain());
        assertNull("Expects null config instance.", this.getConfig());
    }

    /**
     * <p>
     * Initializes the site parameter in request with value 'google'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginDoFilterNotAllowed(WebRequest request) {
        request.addParameter("site", "google");
    }

    /**
     * <p>
     * Calls doFilter() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testDoFilterNotAllowed() throws Exception {
        SimpleFilter filter = new SimpleFilter();
        filter.doFilter(getRequest(), getResponse(), getFilterChain());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects error page returned.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endDoFilterNotAllowed(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text.", content, "Error Page");
    }

}
