/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import javax.servlet.RequestDispatcher;

import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;

import junit.framework.Test;
import junit.framework.TestSuite;

import com.topcoder.testframework.web.TCJspTestCase;

/**
 * <p>
 * This test case extends TCJspTestCase and is used for testing jsp page test.jsp.
 * </p>
 *
 * <p>
 * Note, it is based on the Testing Framework component and demonstrates how to write test case under Testing
 * Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestSimpleJsp extends TCJspTestCase {

    /**
     * <p>
     * Default constructor.
     * </p>
     *
     */
    public TestSimpleJsp() {
        super();
    }

    /**
     * <p>
     * Constructs a test case with the given name.
     * <p>
     *
     * @param name the name of the test case
     */
    public TestSimpleJsp(String name) {
        super(name);
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(TestSimpleJsp.class);
    }

    /**
     * <p>
     * Initializes the userName parameter in request with value 'Jessie'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginJspPage(WebRequest request) {
        request.addParameter("userName", "Jessie");

        // test the implicit objects
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null session instance.", this.getSession());
        assertNull("Expects null out instance.", this.getOut());
        assertNull("Expects null pageContext instance.", this.getPageContext());
        assertNull("Expects null config instance", this.getConfig());
    }

    /**
     * <p>
     * Forwards the current page to /test.jsp.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public void testJspPage() throws Exception {
        // test the implicit objects
        assertNotNull("Expects not null request instance.", this.getRequest());
        assertNotNull("Expects not null response instance.", this.getResponse());
        assertNotNull("Expects not null session instance.", this.getSession());
        assertNotNull("Expects not null out instance.", this.getOut());
        assertNotNull("Expects not null pageContext instance.", this.getPageContext());
        assertNotNull("Expects not null config instance.", this.getConfig());

        RequestDispatcher rd = getConfig().getServletContext().getRequestDispatcher("/test.jsp");
        rd.forward(getRequest(), getResponse());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects "Welcome, Jessie" returned by response.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endJspPage(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text content.", content, "Welcome, Jessie");

        // test the implicit objects
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null session instance.", this.getSession());
        assertNull("Expects null out instance.", this.getOut());
        assertNull("Expects null pageContext instance.", this.getPageContext());
        assertNull("Expects null config instance.", this.getConfig());
    }

}
