/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;

import junit.framework.Test;
import junit.framework.TestSuite;

import com.topcoder.testframework.web.TCServletTestCase;

/**
 * <p>
 * This test case extends TCServletTestCase and is used for testing class SimpleServlet.
 * </p>
 *
 * <p>
 * Note, it is based on the Testing Framework component and demonstrates how to write test case under Testing
 * Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestSimpleServlet extends TCServletTestCase {

    /**
     * <p>
     * Default constructor.
     * </p>
     *
     */
    public TestSimpleServlet() {
        super();
    }

    /**
     * <p>
     * Constructs a test case with the given name.
     * <p>
     *
     * @param name the name of the test case
     */
    public TestSimpleServlet(String name) {
        super(name);
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(TestSimpleServlet.class);
    }

    /**
     * <p>
     * Tests the implicit objects.
     * This method doesn't initializes the userName parameter in request.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginUserNameNotSpecified(WebRequest request) {
        // test the implicit objects
        assertNull("Expects null config instance.", this.getConfig());
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null session instance.", this.getSession());
    }

    /**
     * <p>
     * Calls doGet() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testUserNameNotSpecified() throws Exception {
        // test the implicit objects
        assertNotNull("Expects not null config instance.", this.getConfig());
        assertNotNull("Expects not null request instance.", this.getRequest());
        assertNotNull("Expects not null response instance.", this.getResponse());
        assertNotNull("Expects not null session instance.", this.getSession());

        SimpleServlet servlet = new SimpleServlet();
        servlet.doGet(getRequest(), getResponse());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects "Hello, Stranger!" returned by response.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endUserNameNotSpecified(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text content.", content, "Hello, Stranger!");

        // test the implicit objects
        assertNull("Expects null config instance.", this.getConfig());
        assertNull("Expects null request instance.", this.getRequest());
        assertNull("Expects null response instance.", this.getResponse());
        assertNull("Expects null session instance.", this.getSession());
    }

    /**
     * <p>
     * Initializes the userName parameter in request with value 'Ivern'.
     * </p>
     *
     * @param request the WebRequest instance
     */
    public void beginUserNameSpecified(WebRequest request) {
        request.addParameter("userName", "Ivern");
    }

    /**
     * <p>
     * Calls doGet() method.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testUserNameSpecified() throws Exception {
        SimpleServlet servlet = new SimpleServlet();
        servlet.doGet(getRequest(), getResponse());
    }

    /**
     * <p>
     * Verifies the response text content.
     * </p>
     *
     * <p>
     * Expects "Hello, Ivern!" returned by response.
     * </p>
     *
     * @param response the WebResponse instance
     */
    public void endUserNameSpecified(WebResponse response) {
        String content = response.getText();
        assertEquals("Failed to get correct response text content.", content, "Hello, Ivern!");
    }

}
