/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import java.io.File;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.ZipFileSet;

import com.topcoder.testframework.TestHelper;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for PrepareTestWarTask.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */

public class PrepareTestWarTaskTests extends TestCase {
    /**
     * <p>
     * PrepareTestWarTask instance for testing.
     * </p>
     */
    private PrepareTestWarTask task;

    /**
     * <p>
     * Project instance used for integration unit testing PrepareTestWarTask.
     * </p>
     */
    private Project project;

    /**
     * <p>
     * Default Constructor.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    public PrepareTestWarTaskTests() throws Exception {
        project = TestHelper.getProject("test_files/PrepareTestWarTask.xml");

        TestHelper.clearTempFiles();
    }

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        task = new PrepareTestWarTask();
        task.setProject(new Project());
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        task = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(PrepareTestWarTaskTests.class);
    }

    /**
     * <p>
     * Tests ctor PrepareTestWarTask#PrepareTestWarTask() for accuracy.
     * Expects a new PrepareTestWarTask instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new PrepareTestWarTask instance.", task);
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when srcFile and destFile are specified and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;preparetestwar.war&quot; destFile=&quot;temp/test1.war&quot;/&gt;
     * </p>
     */
    public void testExecute1() {
        project.executeTarget("test1");
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when srcFile attribute is missing and expects BuildException.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar destFile=&quot;temp/test2.war&quot;/&gt;
     * </p>
     */
    public void testExecute2() {
        try {
            project.executeTarget("test2");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when lib element occurs and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;preparetestwar.war&quot; destFile=&quot;temp/test3.war&quot;&gt;
     *     &lt;lib file=&quot;sample.jar&quot;/&gt;
     * &lt;/preparetestwar&gt;
     * </p>
     */
    public void testExecute3() {
        project.executeTarget("test3");
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when classes element occurs and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;preparetestwar.war&quot; destFile=&quot;temp/test4.war&quot;&gt;
     * &lt;classes dir=&quot;../build/classes&quot;/&gt;
     * &lt;/preparetestwar&gt;
     * </p>
     */
    public void testExecute4() {
        project.executeTarget("test4");
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when fileset element occurs and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;preparetestwar.war&quot; destFile=&quot;temp/test5.war&quot;&gt;
     *     &lt;fileset dir=&quot;../conf&quot;/&gt;
     * &lt;/preparetestwar&gt;
     * </p>
     */
    public void testExecute5() {
        project.executeTarget("test5");
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when destFile attribute is missing and expects BuildException.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;preparetestwar.war&quot;/&gt;
     * </p>
     */
    public void testExecute6() {
        try {
            project.executeTarget("test6");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when srcFile attribute specifies a non-exist war file and expects BuildException.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestwar srcFile=&quot;nofile.war&quot; destFile=&quot;temp/test7.war&quot;/&gt;
     * </p>
     *
     */
    public void testExecute7() {
        try {
            project.executeTarget("test7");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#setSrcFile(File) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testSetSrcFile() {
        task.setSrcFile(new File("test_files/preparetestwar.war"));
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#setDestFile(File) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testSetDestFile() {
        task.setDestFile(new File("test_files/temp/test.war"));
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#addLib(ZipFileSet) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testAddLib() {
        ZipFileSet zipFileSet = new ZipFileSet();
        zipFileSet.setFile(new File("test_files/sample.jar"));

        task.addLib(zipFileSet);
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#addFileset(FileSet) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testAddFileset() {
        FileSet fileSet = new FileSet();
        fileSet.setFile(new File("test_files/sample.jar"));

        task.addFileset(fileSet);
    }

    /**
     * <p>
     * Tests PrepareTestWarTask#addClasses(ZipFileSet) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testAddClasses() {
        ZipFileSet zipFileSet = new ZipFileSet();
        zipFileSet.setDir(new File("build/classes"));

        task.addClasses(zipFileSet);
    }
}